## Description

<!-- Describe the changes you made in this Pull Request. -->

## Checklist

<!-- Make sure all items below are checked before submitting the Pull Request. -->

- [ ] I have installed pre-commit on this project (for instance with the `make install-dev` command)
  **before** creating any commit, or I have run successfully the `make lint` command on my changes
- [ ] I have run successfully the `make test` command on my changes
- [ ] I have updated the `README.md` if my changes affected it
